@@ -30,10 +30,18 @@ class Up(Command):
         if check_dockerfile_exists() is False:
             Logger.info("Dockerfile is not exists, Maybe you can rerun `derrick init` to resolve it.")
             return
-
-        status = os.system("/bin/bash -i -c 'docker-compose up -d '")
+        if is_windows() is True:
+            try:
+                import win32api
+                win32api.WinExec('docker-compose up --build -d ')
+            except Exception as e:
+                Logger.error("Can not start your application.Have you installed docker-compose in path?")
+            return
+        status = os.system("/bin/bash -i -c 'docker-compose up --build -d '")
         if status == 0:
             Logger.info("Your application has been up to running! You can run `docker ps` to get exposed ports.")
+        else:
+            Logger.error("Can not start your application.Have you installed docker-compose in path?")
 
     # implement the interface
     def get_help_desc(self):
